@@ -1,6 +1,9 @@
 package testing
 
 import (
+	"bytes"
+	"io/ioutil"
+	"os"
 	"reflect"
 	"testing"
 
@@ -91,16 +94,9 @@ func AssertFinalizers(t *testing.T, obj runtime.Object, finalizers []string) {
 // the expected condition
 func AssertManagedClusterCondition(
 	t *testing.T,
-	actualConditions []clusterv1.StatusCondition,
-	expectedCondition clusterv1.StatusCondition) {
-	var cond *clusterv1.StatusCondition
-	for i := range actualConditions {
-		condition := actualConditions[i]
-		if condition.Type == expectedCondition.Type {
-			cond = &condition
-			break
-		}
-	}
+	actualConditions []metav1.Condition,
+	expectedCondition metav1.Condition) {
+	cond := meta.FindStatusCondition(actualConditions, expectedCondition.Type)
 	if cond == nil {
 		t.Errorf("expected condition %s but got: %s", expectedCondition.Type, cond.Type)
 	}
@@ -191,3 +187,18 @@ func AssertLeaseUpdated(t *testing.T, lease, lastLease *coordinationv1.Lease) {
 		t.Errorf("expected lease updated, but failed")
 	}
 }
+
+// AssertFileExist asserts a given file exists
+func AssertFileExist(t *testing.T, filePath string) {
+	if _, err := os.Stat(filePath); err != nil {
+		t.Errorf("expected file %q exits, but got error %v", filePath, err)
+	}
+}
+
+// AssertFileContent asserts a given file content
+func AssertFileContent(t *testing.T, filePath string, expectedContent []byte) {
+	content, _ := ioutil.ReadFile(filePath)
+	if !bytes.Equal(content, expectedContent) {
+		t.Errorf("expect %v, but got %v", expectedContent, content)
+	}
+}
